package com.emato.cus.supervise.biz.acqGoodsSeat;

import com.emato.cus.supervise.biz.DataConversion;
import com.emato.cus.supervise.constant.Dict;
import com.emato.cus.supervise.domainCus.CusAcqGoodsSeat06;
import com.emato.cus.supervise.domainOmsShop.OmsShopAcqGoodsSeat;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * 门店库位 即oms门店库存
 * @author Scott Chen
 * @version 1.0
 * 2020-03-30 11:27
 */
@Component
public class AcqGoodsOnSeatOmsShopDataConversion implements DataConversion{

    private final static Logger logger = LoggerFactory.getLogger(AcqGoodsOnSeatOmsShopDataConversion.class);

    /**
     * 门店库位 即oms门店库存
     *
     * @param params
     * @return
     */
    @Override
    public List conversion(Map params) {
        logger.info("门店在库库存开始转换, 组装cus数据===========================");

        List<OmsShopAcqGoodsSeat> omsShopList = (List<OmsShopAcqGoodsSeat>) params.get("omsShopList");

        List<CusAcqGoodsSeat06> cusAcqGoodsSeat06List = Lists.newArrayList();

        for (int i = 0; i < omsShopList.size(); i++) {
            try{
                OmsShopAcqGoodsSeat data = omsShopList.get(i);

                String osku = data.getSkuNo();
                if (StringUtils.isBlank(osku)) {
                    logger.error("当前转换的sku为: {}", osku);
                    continue;
                }
                //logger.debug("当前转换的sku为: {}", osku);

                CusAcqGoodsSeat06 cusAcqGoodsSeat06 = new CusAcqGoodsSeat06();

                cusAcqGoodsSeat06.setSeatNo(data.getSeatNo());
                cusAcqGoodsSeat06.setGoodsName(data.getGoodsName());
                cusAcqGoodsSeat06.setCodeTs(data.getCodeTs());
                cusAcqGoodsSeat06.setSkuNo(data.getSkuNo());
                cusAcqGoodsSeat06.setGoodsId(data.getGoodsId());

                cusAcqGoodsSeat06.setgUnit(data.getgUnit());
                cusAcqGoodsSeat06.setgQty(data.getgQty());
                cusAcqGoodsSeat06.setLegalUnit(data.getLegalUnit());
                cusAcqGoodsSeat06.setLegalQty(data.getLegalQty());

                cusAcqGoodsSeat06.setGoodsModel(data.getGoodsModel());
                cusAcqGoodsSeat06.setLocalEmsNo(data.getLocalEmsNo());
                cusAcqGoodsSeat06.setOwnerCode(data.getOwnerCode());
                cusAcqGoodsSeat06.setOwnerName(data.getOwnerName());

                cusAcqGoodsSeat06.setStoreCompanyName(Dict.storeCompanyName);
                cusAcqGoodsSeat06.setStoreUscCode(Dict.storeUscCode);
                cusAcqGoodsSeat06.setStoreCustomsCode(Dict.storeCustomsCode);
                cusAcqGoodsSeat06.setStoreCode(Dict.storeCodeMap.get(data.getStoreCode()));

                cusAcqGoodsSeat06.setCreateTime(LocalDateTime.now());
                cusAcqGoodsSeat06.setCreaterSn(Dict.operater);
                cusAcqGoodsSeat06.setModerSn(Dict.operater);
                cusAcqGoodsSeat06.setModTime(LocalDateTime.now());

                cusAcqGoodsSeat06List.add(cusAcqGoodsSeat06);
            }catch (Exception e){
                logger.error("门店在库库存转换组装cus数据系统异常", e);
            }finally {
                continue;
            }
        }
        logger.info("门店在库库存转换, 组装cus数据结束===========================");
        return cusAcqGoodsSeat06List;
    }
}
