package com.emato.cus.supervise.biz.acqInventoryInfo;

import com.emato.cus.supervise.biz.DataConversion;
import com.emato.cus.supervise.biz.EmsClassConversion;
import com.emato.cus.supervise.constant.Dict;
import com.emato.cus.supervise.domain.WmsAcqInventoryInfo;
import com.emato.cus.supervise.domainCus.CusAcqInventoryInfo03;
import com.emato.cus.supervise.domainOms.OmsMerchInfo;
import com.emato.cus.supervise.domainOms.OmsProductInfo;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author zengjunlin
 * @version 1.0
 * 2018-02-02 14:43
 */
@Component
public class AcqInventoryInfoDataConversion implements DataConversion {

    private static final Logger logger = LoggerFactory.getLogger(AcqInventoryInfoDataConversion.class);

    /**
     * 货物库存
     * 将oms，和wms查询处理的数据进行转换
     *
     * @param params
     * @return
     */
    @Override
    public List conversion(Map params) {
        logger.info("货物库存开始转换oms，wms 组装cus数据===========================");

        List<WmsAcqInventoryInfo> wmsList = (List<WmsAcqInventoryInfo>) params.get("wmsList");

        List<OmsMerchInfo> omsList = (List<OmsMerchInfo>) params.get("omsList");
        final Map<String, OmsMerchInfo> omsMerchInfoMap = omsList.stream().collect(Collectors.toMap(k -> k.getMerchSn() + "_" + k.getEmsClassType(), v -> v));

        List<OmsProductInfo> productInfoList = (List<OmsProductInfo>) params.get("productInfoList");
        final Map<String,OmsProductInfo> omsProductInfoMap =  new HashMap<>();
        //final Map<String,OmsProductInfo> omsProductInfoMap = productInfoList.stream().collect(Collectors.toMap(k->k.getSkuNo(), v->v));
        for (int i = 0, len = productInfoList.size(); i < len; i++) {
            if (omsProductInfoMap.containsKey(productInfoList.get(i).getSkuNo())) {
                continue;
            } else {
                omsProductInfoMap.put(productInfoList.get(i).getSkuNo(), productInfoList.get(i));
            }
        }


        List<CusAcqInventoryInfo03> cusAcqInventoryInfo03List = Lists.newArrayList();

        for (int i = 0; i < wmsList.size(); i++) {
            try {
                WmsAcqInventoryInfo wmsAcqInventoryInfo = wmsList.get(i);

                // WMS抓取中已经针对库位转换了账册分类代码，直接使用
                String emsClassType = wmsAcqInventoryInfo.getEmsClassCode();
                // 拼接商户账册分类
                String merchEmsType = wmsAcqInventoryInfo.getMerchSn() + "_" + emsClassType;
                if (!omsMerchInfoMap.containsKey(merchEmsType)) {
                    logger.error("当前转换的商户账册分类为: {}, WMS传回的商户在OMS中无此账册分类", merchEmsType);
                    continue;
                }
                OmsMerchInfo omsMerchInfo = omsMerchInfoMap.get(merchEmsType);


                OmsProductInfo omsProductInfo = omsProductInfoMap.get(wmsAcqInventoryInfo.getSkuNo());
                String osku = omsProductInfo.getSkuNo();
                if (StringUtils.isBlank(osku)) {
                    logger.error("当前转换的sku为: {}, 对应的产品备案数据异常", osku);
                    continue;
                }
                //logger.debug("当前转换的sku为: {}", omsProductInfo.getSkuNo());

                CusAcqInventoryInfo03 cusAcqInventoryInfo03 = new CusAcqInventoryInfo03();
                cusAcqInventoryInfo03.setGoodsName(wmsAcqInventoryInfo.getGoodsName());

                cusAcqInventoryInfo03.setSkuNo(wmsAcqInventoryInfo.getSkuNo());
                cusAcqInventoryInfo03.setGoodsId(wmsAcqInventoryInfo.getSkuNo());
                cusAcqInventoryInfo03.setCodeTs(omsProductInfo.getCodeTs());

                cusAcqInventoryInfo03.setgUnit(omsProductInfo.getgUnitCode());
                if (wmsAcqInventoryInfo.getgQty() == null) {
                    logger.debug("转换{}为空，qty变为0.0", wmsAcqInventoryInfo.getSkuNo());
                    wmsAcqInventoryInfo.setgQty(0.0);
                }else{
                    logger.debug("转换{}不为空，qty: {}", wmsAcqInventoryInfo.getSkuNo(), wmsAcqInventoryInfo.getgQty());
                }
                cusAcqInventoryInfo03.setgQty(wmsAcqInventoryInfo.getgQty());

                cusAcqInventoryInfo03.setLegalQty(omsProductInfo.getLegalQty());
                cusAcqInventoryInfo03.setLegalUnit(omsProductInfo.getLegalUnit());
                cusAcqInventoryInfo03.setGoodsModel(omsProductInfo.getGoodsModel());

                cusAcqInventoryInfo03.setGoodsModel(omsProductInfoMap.get(wmsAcqInventoryInfo.getSkuNo()).getGoodsModel());

                cusAcqInventoryInfo03.setLocalEmsNo(omsMerchInfo.getCusEmsNo());
                cusAcqInventoryInfo03.setOwnerCode(omsMerchInfo.getOwnerCode());
                cusAcqInventoryInfo03.setOwnerName(omsMerchInfo.getOwnerName());

                cusAcqInventoryInfo03.setStoreCompanyName(Dict.storeCompanyName);
                cusAcqInventoryInfo03.setStoreUscCode(Dict.storeUscCode);
                cusAcqInventoryInfo03.setStoreCustomsCode(Dict.storeCustomsCode);
                if (Dict.storeCodeMap.containsKey(wmsAcqInventoryInfo.getStoreCode())) {
                    cusAcqInventoryInfo03.setStoreCode(Dict.storeCodeMap.get(wmsAcqInventoryInfo.getStoreCode()));
                } else {
                    cusAcqInventoryInfo03.setStoreCode(Dict.storeCodeMap.get("Others"));
                }
                cusAcqInventoryInfo03.setCreateTime(LocalDateTime.now());
                cusAcqInventoryInfo03.setCreaterSn(Dict.operater);
                cusAcqInventoryInfo03.setModerSn(Dict.operater);
                cusAcqInventoryInfo03.setModTime(LocalDateTime.now());

                cusAcqInventoryInfo03List.add(cusAcqInventoryInfo03);

            }catch (Exception e){
                logger.error("货物库存组装cus数据系统异常", e);
            }finally {
                continue;
            }
        }
        logger.info("货物库存组装转换oms，wms 组装cus数据结束===========================");
        return cusAcqInventoryInfo03List;
    }
}
